@@ -39,8 +39,8 @@ class Workspaces(Namespace):
     ) -> Response:
         """
         Retrieve the list of workspaces the user belongs to
-        path: /workspaces
-        method: GET
+        Path: /workspaces
+        Method: GET
 
 
         :return Response
@@ -51,10 +51,10 @@ class Workspaces(Namespace):
     def createWorkspace(self, payload: dict) -> Response:
         """
         Creates a new workspace with the user requesting it as its single owner.
-        path: /workspaces
-        method: POST
+        Path: /workspaces
+        Method: POST
 
-        :param payload: dict content [in: requestBody, req: True]
+        :param payload: dict content
 
         :return Response
         """
@@ -65,10 +65,10 @@ class Workspaces(Namespace):
     def getWorkspace(self, workspace_id: str) -> Response:
         """
         Retrieve workspace info from a workspace ID
-        path: /workspaces/{workspace_id}
-        method: GET
+        Path: /workspaces/{workspace_id}
+        Method: GET
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
+        :param workspace_id: str Workspace ID
 
         :return Response
         """
@@ -78,11 +78,11 @@ class Workspaces(Namespace):
     def updateWorkspace(self, workspace_id: str, payload: dict) -> Response:
         """
         Update workspace info
-        path: /workspaces/{workspace_id}
-        method: PUT
+        Path: /workspaces/{workspace_id}
+        Method: PUT
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
+        :param workspace_id: str Workspace ID
+        :param payload: dict content
 
         :return Response
         """
@@ -93,10 +93,10 @@ class Workspaces(Namespace):
     def deleteWorkspace(self, workspace_id: str) -> Response:
         """
         Delete the workspace with the provided ID
-        path: /workspaces/{workspace_id}
-        method: DELETE
+        Path: /workspaces/{workspace_id}
+        Method: DELETE
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
+        :param workspace_id: str Workspace ID
 
         :return Response
         """
@@ -106,10 +106,10 @@ class Workspaces(Namespace):
     def getWorkspaceMembersList(self, workspace_id: str) -> Response:
         """
         Retrieve the list of members of the given workspace
-        path: /workspaces/{workspace_id}/members
-        method: GET
+        Path: /workspaces/{workspace_id}/members
+        Method: GET
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
+        :param workspace_id: str Workspace ID
 
         :return Response
         """
@@ -120,13 +120,14 @@ class Workspaces(Namespace):
         self, workspace_id: str, user_id: str, payload: dict
     ) -> Response:
         """
-        Update a workspace member role. Workspaces must always have at least one owner, so this operation will fail if trying to remove owner role from the last owner in the workspace.
-        path: /workspaces/{workspace_id}/members/{user_id}
-        method: PUT
+        Update a workspace member role.  Workspaces must always have at least one owner, so this
+        operation will fail if trying to remove owner role from the last owner in the workspace.
+        Path: /workspaces/{workspace_id}/members/{user_id}
+        Method: PUT
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
-        :param user_id: str UserID [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
+        :param workspace_id: str Workspace ID
+        :param user_id: str UserID
+        :param payload: dict content
 
         :return Response
         """
@@ -137,11 +138,11 @@ class Workspaces(Namespace):
     def removeWorkspaceMember(self, workspace_id: str, user_id: str) -> Response:
         """
         Remove the member from the workspace
-        path: /workspaces/{workspace_id}/members/{user_id}
-        method: DELETE
+        Path: /workspaces/{workspace_id}/members/{user_id}
+        Method: DELETE
 
-        :param workspace_id: str Workspace ID [in: path, req: True]
-        :param user_id: str UserID [in: path, req: True]
+        :param workspace_id: str Workspace ID
+        :param user_id: str UserID
 
         :return Response
         """
