@@ -34,36 +34,47 @@ class Records(Namespace):
     base_url = "https://{workspaceId}.{regionId}.xata.sh"
     scope = "workspace"
 
-    def branchTransaction(self, db_branch_name: str, payload: dict) -> Response:
+    def branchTransaction(
+        self, payload: dict, db_name: str = None, branch_name: str = None
+    ) -> Response:
         """
         Execute a transaction on a branch
-        path: /db/{db_branch_name}/transaction
-        method: POST
+        Path: /db/{db_branch_name}/transaction
+        Method: POST
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/transaction"
         headers = {"content-type": "application/json"}
         return self.request("POST", url_path, headers, payload)
 
     def insertRecord(
-        self, db_branch_name: str, table_name: str, payload: dict, columns: list = None
+        self,
+        table_name: str,
+        payload: dict,
+        db_name: str = None,
+        branch_name: str = None,
+        columns: list = None,
     ) -> Response:
         """
         Insert a new Record into the Table
-        path: /db/{db_branch_name}/tables/{table_name}/data
-        method: POST
+        Path: /db/{db_branch_name}/tables/{table_name}/data
+        Method: POST
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
+        :param table_name: str The Table name
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data"
         if columns is not None:
             url_path += "?columns=%s" % ",".join(columns)
@@ -71,20 +82,27 @@ class Records(Namespace):
         return self.request("POST", url_path, headers, payload)
 
     def getRecord(
-        self, db_branch_name: str, table_name: str, record_id: str, columns: list = None
+        self,
+        table_name: str,
+        record_id: str,
+        db_name: str = None,
+        branch_name: str = None,
+        columns: list = None,
     ) -> Response:
         """
         Retrieve record by ID
-        path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
-        method: GET
+        Path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
+        Method: GET
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param record_id: str The Record name [in: path, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
+        :param table_name: str The Table name
+        :param record_id: str The Record name
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data/{record_id}"
         if columns is not None:
             url_path += "?columns=%s" % ",".join(columns)
@@ -92,29 +110,34 @@ class Records(Namespace):
 
     def insertRecordWithID(
         self,
-        db_branch_name: str,
         table_name: str,
         record_id: str,
         payload: dict,
+        db_name: str = None,
+        branch_name: str = None,
         columns: list = None,
         createOnly: bool = None,
         ifVersion: int = None,
     ) -> Response:
         """
-        By default, IDs are auto-generated when data is insterted into Xata. Sending a request to this endpoint allows us to insert a record with a pre-existing ID, bypassing the default automatic ID generation.
-        path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
-        method: PUT
+        By default, IDs are auto-generated when data is insterted into Xata.  Sending a request to
+        this endpoint allows us to insert a record with a pre-existing ID, bypassing the default
+        automatic ID generation.
+        Path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
+        Method: PUT
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param record_id: str The Record name [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
-        :param createOnly: bool = None  [in: query, req: False]
-        :param ifVersion: int = None  [in: query, req: False]
+        :param table_name: str The Table name
+        :param record_id: str The Record name
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
+        :param createOnly: bool = None
+        :param ifVersion: int = None
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data/{record_id}"
         query_params = []
         if columns is not None:
@@ -130,27 +153,30 @@ class Records(Namespace):
 
     def upsertRecordWithID(
         self,
-        db_branch_name: str,
         table_name: str,
         record_id: str,
         payload: dict,
+        db_name: str = None,
+        branch_name: str = None,
         columns: list = None,
         ifVersion: int = None,
     ) -> Response:
         """
         Upsert record with ID
-        path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
-        method: POST
+        Path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
+        Method: POST
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param record_id: str The Record name [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
-        :param ifVersion: int = None  [in: query, req: False]
+        :param table_name: str The Table name
+        :param record_id: str The Record name
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
+        :param ifVersion: int = None
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data/{record_id}"
         query_params = []
         if columns is not None:
@@ -163,20 +189,27 @@ class Records(Namespace):
         return self.request("POST", url_path, headers, payload)
 
     def deleteRecord(
-        self, db_branch_name: str, table_name: str, record_id: str, columns: list = None
+        self,
+        table_name: str,
+        record_id: str,
+        db_name: str = None,
+        branch_name: str = None,
+        columns: list = None,
     ) -> Response:
         """
         Delete record from table
-        path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
-        method: DELETE
+        Path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
+        Method: DELETE
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param record_id: str The Record name [in: path, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
+        :param table_name: str The Table name
+        :param record_id: str The Record name
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data/{record_id}"
         if columns is not None:
             url_path += "?columns=%s" % ",".join(columns)
@@ -184,27 +217,30 @@ class Records(Namespace):
 
     def updateRecordWithID(
         self,
-        db_branch_name: str,
         table_name: str,
         record_id: str,
         payload: dict,
+        db_name: str = None,
+        branch_name: str = None,
         columns: list = None,
         ifVersion: int = None,
     ) -> Response:
         """
         Update record with ID
-        path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
-        method: PATCH
+        Path: /db/{db_branch_name}/tables/{table_name}/data/{record_id}
+        Method: PATCH
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param record_id: str The Record name [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
-        :param ifVersion: int = None  [in: query, req: False]
+        :param table_name: str The Table name
+        :param record_id: str The Record name
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
+        :param ifVersion: int = None
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/data/{record_id}"
         query_params = []
         if columns is not None:
@@ -217,20 +253,27 @@ class Records(Namespace):
         return self.request("PATCH", url_path, headers, payload)
 
     def bulkInsertTableRecords(
-        self, db_branch_name: str, table_name: str, payload: dict, columns: list = None
+        self,
+        table_name: str,
+        payload: dict,
+        db_name: str = None,
+        branch_name: str = None,
+        columns: list = None,
     ) -> Response:
         """
         Bulk insert records
-        path: /db/{db_branch_name}/tables/{table_name}/bulk
-        method: POST
+        Path: /db/{db_branch_name}/tables/{table_name}/bulk
+        Method: POST
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
-        :param table_name: str The Table name [in: path, req: True]
-        :param payload: dict content [in: requestBody, req: True]
-        :param columns: list = None Column filters [in: query, req: False]
+        :param table_name: str The Table name
+        :param payload: dict content
+        :param db_name: str = None The name of the database to query. Default: database name from the client.
+        :param branch_name: str = None The name of the branch to query. Default: branch name from the client.
+        :param columns: list = None Column filters
 
         :return Response
         """
+        db_branch_name = self.client.get_db_branch_name(db_name, branch_name)
         url_path = f"/db/{db_branch_name}/tables/{table_name}/bulk"
         if columns is not None:
             url_path += "?columns=%s" % ",".join(columns)
